/*
 Tecnisa - Tecnologia em Informtica

 Nome: CONSISTE_FISCAL

  Descrio:
  Funo para detectar incosistncias fiscais na nota lanada.

  OBS.: As inconsistncias consideram os bloqueios da tabela CONSISTEFISCAL e
        tambm as tabelas ALIQUOTACSTNFE e NATUBCALCCFOP (importante manter os registros destas tabelas atualizados)
*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CONSISTE_FISCAL'
             AND TYPE = 'TF'
             AND U.UID = O.UID
             AND U.NAME = USER)
DROP FUNCTION CONSISTE_FISCAL
GO

CREATE FUNCTION CONSISTE_FISCAL
(
@P_CDFILIAL   VARCHAR(4),
@P_NRLANCTONF VARCHAR(10)
)
returns @TRAVAFISCAL_TABLE table
  (
CDIMPOSTO        VARCHAR(02),
NRSEQITPROD      VARCHAR(04),
CDARVPROD        VARCHAR(20),
NMPRODUTO        VARCHAR(50),
NRSEQCONSISTE    VARCHAR(40),
DSCONSISTENCIA   VARCHAR(250),
CDREGRAIT        VARCHAR(10)
)
AS
BEGIN
   DECLARE @V_IDSISTEMA                VARCHAR(03);
   DECLARE @V_IDATATUS                 VARCHAR(01);
   DECLARE @V_IDSTATUSNFE              VARCHAR(01);
   DECLARE @V_IDENTRSAIDOP             VARCHAR(01);
   DECLARE @V_TRAVA                    VARCHAR(10);
   DECLARE @V_CDIMPOSTO                VARCHAR(02);
   DECLARE @V_NRSEQITPROD              VARCHAR(04);
   DECLARE @V_CONFALIQ                 VARCHAR(30);
   DECLARE @V_IMPOSTO                  VARCHAR(30);
   DECLARE @V_CDFILIMOVI               VARCHAR(04);
   DECLARE @V_IDCUMUPISCOFIL           VARCHAR(01);
   DECLARE @V_CDFILIEMIT               VARCHAR(04);
   DECLARE @V_CDFILIRECE               VARCHAR(04);
   DECLARE @V_COFINS                   VARCHAR(02);
   DECLARE @V_COUNT                    INTEGER;
   DECLARE @V_VRBASECALCIT             DOUBLE PRECISION;
   DECLARE @V_CDSITUTRIBITNFE          VARCHAR(02);
   DECLARE @V_CDTPCREDPICOITE          VARCHAR(03);
   DECLARE @V_CDNATUBCALPCIT           VARCHAR(02);
   DECLARE @V_PIS                      VARCHAR(02);
   DECLARE @V_DESC                     VARCHAR(250);
   DECLARE @V_ITEM_CDFILIAL            VARCHAR(04);
   DECLARE @V_ITEM_NRLANCTONF          VARCHAR(10);
   DECLARE @V_ITEM_NRSEQITPROD         VARCHAR(04);
   DECLARE @V_ITEM_CDFISOPEITEM        VARCHAR(04);
   DECLARE @V_ITEM_CDSITUTRIBPR        VARCHAR(03);
   DECLARE @V_TRAVA_CDIMPOSTO          VARCHAR(02);
   DECLARE @V_TRAVA_NRSEQCONSISTE      VARCHAR(10);
   DECLARE @V_TRAVA_CDFISCOPER         VARCHAR(10);
   DECLARE @V_TRAVA_IDTPALIQUOTA       VARCHAR(01);
   DECLARE @V_TRAVA_CDSITUTRIB         VARCHAR(02);
   DECLARE @V_TRAVA_IDTPBASECALC       VARCHAR(01);
   DECLARE @V_TRAVA_IDTPVRIMPOSTO      VARCHAR(01);
   DECLARE @V_TRAVA_IDCONSISTELANC     VARCHAR(01);
   DECLARE @V_TRAVA_IDCONSISTEAPRO     VARCHAR(01);
   DECLARE @V_TRAVA_IDBLOQADMI         VARCHAR(01);
   DECLARE @V_TRAVA_CDFISCAL           VARCHAR(01);
   DECLARE @V_TRAVA_IDCONSPREDEFI      VARCHAR(01);
   DECLARE @V_TRAVA_IDENTRSAIDOP       VARCHAR(01);
   DECLARE @V_TRAVA_CDIMPOSTONFE       VARCHAR(02);
   DECLARE @V_TRAVA_CDCST1DIGT         VARCHAR(01);
   DECLARE @V_TRAVA_CDTPCREDPICOITE    VARCHAR(03);
   DECLARE @V_TRAVA_DSCONSISTENCIA     VARCHAR(250);
   DECLARE @V_IMPOSTO_CDIMPOSTO        VARCHAR(02);
   DECLARE @V_IMPOSTO_VRCONTITIMP      DOUBLE PRECISION;
   DECLARE @V_IMPOSTO_VRBASECALCIT     DOUBLE PRECISION;
   DECLARE @V_IMPOSTO_VRIMPOSTOIT      DOUBLE PRECISION;
   DECLARE @V_IMPOSTO_CDSITUTRIBITNFE  VARCHAR(02);
   DECLARE @V_IMPOSTO_CDSITUTRIBIT     VARCHAR(03);
   DECLARE @V_IMPOSTO_CDFISCOPERIT     VARCHAR(04);
   DECLARE @V_IMPOSTO_CDFISCALIT       VARCHAR(01);
   DECLARE @V_IMPOSTO_VRALIQITEM       DOUBLE PRECISION;
   DECLARE @V_IMPOSTO_ID               VARCHAR(01);
   DECLARE @V_IMP_CDIMPOSTO            VARCHAR(02);
   DECLARE @V_IMP_VRCONTITIMP          DOUBLE PRECISION;
   DECLARE @V_IMP_VRBASECALCIT         DOUBLE PRECISION;
   DECLARE @V_IMP_VRIMPOSTOIT          DOUBLE PRECISION;
   DECLARE @V_IMP_CDSITUTRIBITNFE      VARCHAR(02);
   DECLARE @V_IMP_CDSITUTRIBIT         VARCHAR(03);
   DECLARE @V_IMP_CDFISCOPERIT         VARCHAR(04);
   DECLARE @V_IMP_CDFISCALIT           VARCHAR(01);
   DECLARE @V_IMP_CDIMPOSTONFE         VARCHAR(02);
   DECLARE @V_IMP_VRALIQITEM           DOUBLE PRECISION;
   DECLARE @V_IMP_IDUTVLRQTDEIMPO      VARCHAR(01);
   DECLARE @V_IMP_CDTPCREDPICOITE      VARCHAR(03);
   DECLARE @V_IMP_CDNATUBCALPCIT       VARCHAR(02);
   DECLARE @V_ITEM_CDARVPROD           VARCHAR(20);
   DECLARE @V_ITEM_NMPRODUTO           VARCHAR(250);
   DECLARE @V_IDUTCONSISTE             VARCHAR(01);
   DECLARE @V_CDSITUCRT                VARCHAR(01);
   DECLARE @V_IDIMPORECUP              VARCHAR(01);
   DECLARE @V_IMP_IDIMPORECUP          VARCHAR(01);
   DECLARE @V_IMPOSTO_NRITPROIMPOS     VARCHAR(01);
   DECLARE @V_IMPOSTO_VRPERREDBCIT     DOUBLE PRECISION;
   DECLARE @V_ITEM_CDFISCOPERSN        VARCHAR(04);
   DECLARE @V_CDTIPOOPER               VARCHAR(02);
   DECLARE @V_IMPOSTO_CDREGRAIT        VARCHAR(10);
   DECLARE @V_CDREGRAIT                VARCHAR(10);
   DECLARE @V_IMP_CDREGRAIT            VARCHAR(10);
   DECLARE @V_IMP_NRITPROIMPOS         VARCHAR(01);

   SELECT @V_IDUTCONSISTE = MAX(IDUTCONSISTE)
     FROM PARAMFISCAL;

   IF (@V_IDUTCONSISTE  = 'S') BEGIN
      SELECT @V_IDSISTEMA = MAX(IDSISTEMA), @V_IDATATUS = MAX(IDSTATUS), @V_IDSTATUSNFE = MAX(IDSTATUSNFE), @V_IDENTRSAIDOP = MAX(IDENTRSAIDOP), @V_CDFILIEMIT = MAX(CDFILIEMIT), @V_CDFILIRECE = MAX(CDFILIRECE),
             @V_CDSITUCRT = MAX(CDSITUCRT), @V_CDTIPOOPER = MAX(CDTIPOOPER)
        FROM NOTAFISCAL N LEFT JOIN PARAMEMPRESA P
                          ON N.CDEMPRESA = P.CDEMPRESA
       WHERE CDFILIAL   = @P_CDFILIAL
         AND NRLANCTONF = @P_NRLANCTONF;

      DECLARE C_ITEM CURSOR FOR
         SELECT CDFILIAL, NRLANCTONF, NRSEQITPROD, CDFISOPEITEM, CDSITUTRIBPR, P.CDARVPROD, P.NMPRODUTO, I.CDFISCOPERSN
           FROM ITEMPRODUTO I, PRODUTO P
          WHERE CDFILIAL   = @P_CDFILIAL
            AND NRLANCTONF = @P_NRLANCTONF
            AND I.CDPRODUTO = P.CDPRODUTO
         ORDER BY CDFILIAL, NRLANCTONF, NRSEQITPROD;
      OPEN C_ITEM;
      FETCH NEXT FROM C_ITEM INTO @V_ITEM_CDFILIAL, @V_ITEM_NRLANCTONF, @V_ITEM_NRSEQITPROD, @V_ITEM_CDFISOPEITEM, @V_ITEM_CDSITUTRIBPR,
                                  @V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_ITEM_CDFISCOPERSN;
      WHILE (@@FETCH_STATUS = 0)
      BEGIN
         IF (@V_ITEM_CDFISOPEITEM IS NOT NULL) BEGIN
            IF (LEN(@V_ITEM_CDFISOPEITEM) <> 4) BEGIN
               SET @V_TRAVA       = 'CFOP_TAM_INV';
               SET @V_DESC        = 'CFOP com tamanho invlido. O CFOP do item deve possuir 4 dgitos.';
               SET @V_CDIMPOSTO   = '';
               SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;

               INSERT INTO @TRAVAFISCAL_TABLE
                  (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO)
                VALUES
                  (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO);

            END
            ELSE BEGIN
               IF (@V_IDENTRSAIDOP = 'E') BEGIN
                  IF (SUBSTRING(@V_ITEM_CDFISOPEITEM, 1, 1) NOT IN ('1', '2', '3')) BEGIN
                     SET @V_TRAVA       = 'CFOP_1DIG_INV';
                     SET @V_DESC        = '1 Dgito do CFOP invlido. O CFOP de operaes de entrada se inicia com 1,2 ou 3.';
                     SET @V_CDIMPOSTO   = '';
                     SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;

                     INSERT INTO @TRAVAFISCAL_TABLE
                        (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO)
                      VALUES
                        (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO);
                  END;
               END
               ELSE BEGIN
                  IF (SUBSTRING(@V_ITEM_CDFISOPEITEM, 1, 1) NOT IN ('5', '6', '7')) BEGIN
                     SET @V_TRAVA       = 'CFOP_1DIG_INV';
                     SET @V_DESC        = '1 Dgito do CFOP invlido. O CFOP de operaes de sada se inicia com 5,6 ou 7.';
                     SET @V_CDIMPOSTO   = '';
                     SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;

                     INSERT INTO @TRAVAFISCAL_TABLE
                        (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO)
                      VALUES
                        (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO);
                  END;
               END;
            END;
         END;
         DECLARE C_TRAVA CURSOR FOR
            SELECT I.CDIMPOSTO, NRSEQCONSISTE, CDFISCOPER, IDTPALIQUOTA, CDSITUTRIB, IDTPBASECALC,
                   IDTPVRIMPOSTO, IDCONSISTELANC, IDCONSISTEAPRO, IDBLOQADMI, CDFISCAL, IDCONSPREDEFI,
                   IDENTRSAIDOP, I.CDIMPOSTONFE, CDCST1DIGT,  CDTPCREDPICOITE, DSCONSISTENCIA
              FROM CONSISTEFISCAL C, IMPOSTO I
             WHERE ((IDENTRSAIDOP = @V_IDENTRSAIDOP) OR (IDENTRSAIDOP = 'T'))
               AND IDCONSPREDEFI = 'S'
               AND IDCONSATIVA = 'S'
               AND C.CDIMPOSTO = I.CDIMPOSTONFE;
         OPEN C_TRAVA;
         FETCH NEXT FROM C_TRAVA INTO @V_TRAVA_CDIMPOSTO, @V_TRAVA_NRSEQCONSISTE, @V_TRAVA_CDFISCOPER, @V_TRAVA_IDTPALIQUOTA, @V_TRAVA_CDSITUTRIB, @V_TRAVA_IDTPBASECALC,
                                      @V_TRAVA_IDTPVRIMPOSTO, @V_TRAVA_IDCONSISTELANC, @V_TRAVA_IDCONSISTEAPRO, @V_TRAVA_IDBLOQADMI, @V_TRAVA_CDFISCAL, @V_TRAVA_IDCONSPREDEFI,
                                      @V_TRAVA_IDENTRSAIDOP, @V_TRAVA_CDIMPOSTONFE, @V_TRAVA_CDCST1DIGT, @V_TRAVA_CDTPCREDPICOITE, @V_TRAVA_DSCONSISTENCIA;
         WHILE (@@FETCH_STATUS = 0)
         BEGIN
            SET @V_TRAVA       = NULL;
            SET @V_DESC        = NULL;
            SET @V_CDIMPOSTO   = NULL;
            SET @V_NRSEQITPROD = NULL;

            DECLARE C_IMPOSTO CURSOR FOR
               SELECT CDIMPOSTO, VRCONTITIMP, VRBASECALCIT, VRIMPOSTOIT, CDSITUTRIBITNFE, CDSITUTRIBIT,
                      CDFISCOPERIT, CDFISCALIT, VRALIQITEM, NRITPROIMPOS, VRPERREDBCIT, CDREGRAIT, 'A'
                 FROM ITEMPROIMPOS
                WHERE CDFILIAL    = @P_CDFILIAL
                  AND NRLANCTONF  = @P_NRLANCTONF
                  AND NRSEQITPROD = @V_ITEM_NRSEQITPROD
                  AND CDIMPOSTO   = @V_TRAVA_CDIMPOSTO
                  AND ((CDFISCOPERIT = @V_TRAVA_CDFISCOPER) OR (ISNULL(@V_TRAVA_CDFISCOPER,'T') = 'T'))
                  AND ((CDSITUTRIBITNFE = @V_TRAVA_CDSITUTRIB) OR (ISNULL(@V_TRAVA_CDSITUTRIB, 'T') = 'T'))
                  AND ((SUBSTRING(CDSITUTRIBIT, 1, 1) = @V_TRAVA_CDCST1DIGT) OR (ISNULL(@V_TRAVA_CDCST1DIGT, 'T') = 'T'))
                  AND ((CDFISCALIT = @V_TRAVA_CDFISCAL) OR (ISNULL(@V_TRAVA_CDFISCAL, 'T') = 'T'))
                  AND ((CDTPCREDPICOITE = @V_TRAVA_CDTPCREDPICOITE) OR (ISNULL(@V_TRAVA_CDTPCREDPICOITE, 'T') = 'T'))
               UNION ALL
               SELECT CDIMPOSTO, VRCONTITIMP, VRBASECALCIT, VRIMPOSTOIT, CDSITUTRIBITNFE, CDSITUTRIBIT,
                      CDFISCOPERIT, CDFISCALIT, VRALIQITEM, NRITPROIMPOS, VRPERREDBCIT, CDREGRAIT, 'B'
                 FROM ITEMPROIMPOS
                WHERE CDFILIAL    = @P_CDFILIAL
                  AND NRLANCTONF  = @P_NRLANCTONF
                  AND NRSEQITPROD = @V_ITEM_NRSEQITPROD
                  AND CDIMPOSTO   = @V_TRAVA_CDIMPOSTO
                  AND ((CHARINDEX(SUBSTRING(CDFISCOPERIT, 1, 3), @V_TRAVA_CDFISCOPER) =  1) OR (ISNULL(@V_TRAVA_CDFISCOPER,'T') = 'T'))
                  AND ((CDSITUTRIBITNFE = @V_TRAVA_CDSITUTRIB) OR (ISNULL(@V_TRAVA_CDSITUTRIB, 'T') = 'T'))
                  AND ((SUBSTRING(CDSITUTRIBIT, 1, 1) = @V_TRAVA_CDCST1DIGT) OR (ISNULL(@V_TRAVA_CDCST1DIGT, 'T') = 'T'))
                  AND ((CDFISCALIT = @V_TRAVA_CDFISCAL) OR (ISNULL(@V_TRAVA_CDFISCAL, 'T') = 'T'))
                  AND ((CDTPCREDPICOITE = @V_TRAVA_CDTPCREDPICOITE) OR (ISNULL(@V_TRAVA_CDTPCREDPICOITE, 'T') = 'T'));
            OPEN C_IMPOSTO;
            FETCH NEXT FROM C_IMPOSTO INTO @V_IMPOSTO_CDIMPOSTO, @V_IMPOSTO_VRCONTITIMP, @V_IMPOSTO_VRBASECALCIT, @V_IMPOSTO_VRIMPOSTOIT, @V_IMPOSTO_CDSITUTRIBITNFE, @V_IMPOSTO_CDSITUTRIBIT,
                                           @V_IMPOSTO_CDFISCOPERIT, @V_IMPOSTO_CDFISCALIT, @V_IMPOSTO_VRALIQITEM, @V_IMPOSTO_NRITPROIMPOS, @V_IMPOSTO_VRPERREDBCIT, @V_IMPOSTO_CDREGRAIT, @V_IMPOSTO_ID;
            WHILE (@@FETCH_STATUS = 0)
            BEGIN
               IF (@V_CDTIPOOPER <> '03') BEGIN
                  IF ((@V_TRAVA_IDTPBASECALC  = '0') AND (@V_TRAVA_IDTPVRIMPOSTO = '0') AND (@V_TRAVA_IDTPALIQUOTA = '0')) BEGIN
                     IF NOT((@V_IMPOSTO_NRITPROIMPOS = '2') AND (@V_IMPOSTO_VRPERREDBCIT > 0)) BEGIN
                        IF (@V_TRAVA_CDSITUTRIB IS NOT NULL) BEGIN
                           IF (@V_CDSITUCRT = '3') BEGIN
                              SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                              SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                              SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                           END;
                        END
                        ELSE BEGIN
                           SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                           SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                           SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                           SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                           SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                        END;
                     END;
                  END;
                  IF (@V_TRAVA_IDBLOQADMI = 'B') BEGIN
                     IF (@V_CDSITUCRT = '3') BEGIN
                        IF (@V_TRAVA_IDTPBASECALC  = '1') BEGIN
                           IF (@V_IMPOSTO_VRBASECALCIT < 0) BEGIN
                              SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                              SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                              SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                           END;
                           IF (@V_IMPOSTO_VRCONTITIMP < 0) BEGIN
                              SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                              SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                              SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                           END;
                        END
                        ELSE BEGIN
                           IF (@V_TRAVA_IDTPBASECALC  = '2') BEGIN
                              IF (@V_IMPOSTO_VRBASECALCIT = 0) BEGIN
                                 SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                                 SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                                 SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                                 SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                                 SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                              END;
                           END
                           ELSE BEGIN
                              IF (@V_TRAVA_IDTPBASECALC  = '3') BEGIN
                                 IF (@V_IMPOSTO_VRBASECALCIT >= 0) BEGIN
                                    SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                                    SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                                    SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                                    SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                                    SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                                 END;
                              END
                              ELSE BEGIN
                                 IF (@V_TRAVA_IDTPBASECALC  = '4') BEGIN
                                    IF (@V_IMPOSTO_VRBASECALCIT <> 0) BEGIN
                                       SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                                       SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                                       SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                                       SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                                       SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                                    END;
                                 END;
                              END;
                           END;
                        END;

                        IF (@V_TRAVA_IDTPVRIMPOSTO  = '1') BEGIN
                           IF (@V_IMPOSTO_VRIMPOSTOIT < 0) BEGIN
                              SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                              SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                              SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                           END;
                        END
                        ELSE BEGIN
                           IF (@V_TRAVA_IDTPVRIMPOSTO  = '2') BEGIN
                              IF (@V_IMPOSTO_VRIMPOSTOIT = 0) BEGIN
                                 SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                                 SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                                 SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                                 SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                                 SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                              END;
                           END
                           ELSE BEGIN
                              IF (@V_TRAVA_IDTPVRIMPOSTO  = '3') BEGIN
                                 IF (@V_IMPOSTO_VRIMPOSTOIT >= 0) BEGIN
                                    SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                                    SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                                    SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                                    SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                                    SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                                 END;
                              END
                              ELSE BEGIN
                                 IF (@V_TRAVA_IDTPVRIMPOSTO  = '4') BEGIN
                                    IF (@V_IMPOSTO_VRIMPOSTOIT <> 0) BEGIN
                                       SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                                       SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                                       SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                                       SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                                       SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                                    END;
                                 END;
                              END;
                           END;
                        END;

                        IF (@V_TRAVA_IDTPALIQUOTA  = '1') BEGIN
                           IF (@V_IMPOSTO_VRALIQITEM < 0) BEGIN
                              SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                              SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                              SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                           END;
                        END
                        ELSE BEGIN
                           IF (@V_TRAVA_IDTPALIQUOTA  = '2') BEGIN
                              IF (@V_IMPOSTO_VRALIQITEM = 0) BEGIN
                                 SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                                 SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                                 SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                                 SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                                 SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                              END;
                           END
                           ELSE BEGIN
                              IF (@V_TRAVA_IDTPALIQUOTA  = '3') BEGIN
                                 IF (@V_IMPOSTO_VRALIQITEM >= 0) BEGIN
                                    SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                                    SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                                    SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                                    SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                                    SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                                 END;
                              END
                              ELSE BEGIN
                                 IF (@V_TRAVA_IDTPALIQUOTA  = '4') BEGIN
                                    IF (@V_IMPOSTO_VRALIQITEM <> 0) BEGIN
                                       SET @V_TRAVA       = @V_TRAVA_NRSEQCONSISTE;
                                       SET @V_DESC        = @V_TRAVA_DSCONSISTENCIA;
                                       SET @V_CDIMPOSTO   = @V_TRAVA_CDIMPOSTO;
                                       SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                                       SET @V_CDREGRAIT   = @V_IMPOSTO_CDREGRAIT;
                                    END;
                                 END;
                              END;
                           END;
                        END;
                     END;
                  END;
               END;

               FETCH NEXT FROM C_IMPOSTO INTO @V_IMPOSTO_CDIMPOSTO, @V_IMPOSTO_VRCONTITIMP, @V_IMPOSTO_VRBASECALCIT, @V_IMPOSTO_VRIMPOSTOIT, @V_IMPOSTO_CDSITUTRIBITNFE, @V_IMPOSTO_CDSITUTRIBIT,
                                              @V_IMPOSTO_CDFISCOPERIT, @V_IMPOSTO_CDFISCALIT, @V_IMPOSTO_VRALIQITEM, @V_IMPOSTO_NRITPROIMPOS, @V_IMPOSTO_VRPERREDBCIT, @V_IMPOSTO_CDREGRAIT, @V_IMPOSTO_ID;
            END;
            CLOSE C_IMPOSTO;
            DEALLOCATE C_IMPOSTO;

            IF (@V_TRAVA IS NOT NULL) BEGIN

               INSERT INTO @TRAVAFISCAL_TABLE
                  (CDIMPOSTO, NRSEQITPROD, CDARVPROD, NMPRODUTO, NRSEQCONSISTE, DSCONSISTENCIA, CDREGRAIT)
                VALUES
                  (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_TRAVA, @V_DESC, @V_CDREGRAIT);
            END;
            FETCH NEXT FROM C_TRAVA INTO @V_TRAVA_CDIMPOSTO, @V_TRAVA_NRSEQCONSISTE, @V_TRAVA_CDFISCOPER, @V_TRAVA_IDTPALIQUOTA, @V_TRAVA_CDSITUTRIB, @V_TRAVA_IDTPBASECALC,
                                         @V_TRAVA_IDTPVRIMPOSTO, @V_TRAVA_IDCONSISTELANC, @V_TRAVA_IDCONSISTEAPRO, @V_TRAVA_IDBLOQADMI, @V_TRAVA_CDFISCAL, @V_TRAVA_IDCONSPREDEFI,
                                         @V_TRAVA_IDENTRSAIDOP, @V_TRAVA_CDIMPOSTONFE, @V_TRAVA_CDCST1DIGT, @V_TRAVA_CDTPCREDPICOITE, @V_TRAVA_DSCONSISTENCIA;
         END;
         CLOSE C_TRAVA;
         DEALLOCATE C_TRAVA;

         DECLARE C_IMP CURSOR FOR
            SELECT IT.CDIMPOSTO, VRCONTITIMP, VRBASECALCIT, VRIMPOSTOIT, CDSITUTRIBITNFE, CDSITUTRIBIT,
                   CDFISCOPERIT, CDFISCALIT, I.CDIMPOSTONFE, IT.VRALIQITEM, I.IDUTVLRQTDEIMPO, IT.CDTPCREDPICOITE,
                   IT.CDNATUBCALPCIT, I.IDIMPORECUP, IT.CDREGRAIT, IT.NRITPROIMPOS
              FROM ITEMPROIMPOS IT, IMPOSTO I
             WHERE CDFILIAL     = @P_CDFILIAL
               AND NRLANCTONF   = @P_NRLANCTONF
               AND NRSEQITPROD  = @V_ITEM_NRSEQITPROD
               AND IT.CDIMPOSTO = I.CDIMPOSTO;
         OPEN C_IMP;
         FETCH NEXT FROM C_IMP INTO @V_IMP_CDIMPOSTO, @V_IMP_VRCONTITIMP, @V_IMP_VRBASECALCIT, @V_IMP_VRIMPOSTOIT, @V_IMP_CDSITUTRIBITNFE, @V_IMP_CDSITUTRIBIT,
                                    @V_IMP_CDFISCOPERIT, @V_IMP_CDFISCALIT, @V_IMP_CDIMPOSTONFE, @V_IMP_VRALIQITEM, @V_IMP_IDUTVLRQTDEIMPO, @V_IMP_CDTPCREDPICOITE,
                                    @V_IMP_CDNATUBCALPCIT, @V_IMP_IDIMPORECUP, @V_IMP_CDREGRAIT, @V_IMP_NRITPROIMPOS;
         WHILE (@@FETCH_STATUS = 0)
         BEGIN
            SET @V_TRAVA       = NULL;
            SET @V_DESC        = NULL;
            SET @V_CDIMPOSTO   = NULL;
            SET @V_NRSEQITPROD = NULL;
            SET @V_CDREGRAIT   = NULL;

            IF (@V_CDTIPOOPER <> '03') BEGIN
               /*ICMS*/
               IF (@V_IMP_CDIMPOSTONFE = '00') BEGIN
                  IF ((@V_ITEM_CDFISOPEITEM IS NULL) OR (@V_IMP_CDFISCOPERIT IS NULL)) BEGIN
                     SET @V_TRAVA       = 'ICMS_CFOP';
                     SET @V_DESC        = 'Notas com ICMS devem possuir CFOP.';
                     SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                     SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                     SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                     INSERT INTO @TRAVAFISCAL_TABLE
                       (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                     VALUES
                       (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                  END;
                  IF @V_CDSITUCRT = '3' BEGIN
                     IF (@V_ITEM_CDSITUTRIBPR IS NULL) BEGIN
                        SET @V_TRAVA       = 'ERRO_CSTITEM';
                        SET @V_DESC        = 'Notas com ICMS devem possuir CST.';
                        SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                        SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                        SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                        INSERT INTO @TRAVAFISCAL_TABLE
                           (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                        VALUES
                           (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO,@V_CDREGRAIT);
                     END;
                     IF (@V_ITEM_CDSITUTRIBPR <> @V_IMP_CDSITUTRIBIT) BEGIN
                        SET @V_TRAVA       = 'ERRO_CST';
                        SET @V_DESC        = 'Situao tributria do item deve ser igual a situao tributria do ICMS.';
                        SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                        SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                        SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                        INSERT INTO @TRAVAFISCAL_TABLE
                           (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                        VALUES
                           (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                     END;
                     IF (@V_IMP_CDSITUTRIBITNFE <> SUBSTRING(@V_IMP_CDSITUTRIBIT, 2, 2)) BEGIN
                        SET @V_TRAVA       = 'CSTNFE_CST';
                        SET @V_DESC        = 'Situao tributria do ICMS deve ser igual a situao tributria eletrnica do ICMS.';
                        SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                        SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                        SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                        INSERT INTO @TRAVAFISCAL_TABLE
                           (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                        VALUES
                           (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                     END;
                     IF (@V_IMP_CDSITUTRIBITNFE = '20') BEGIN
                        SELECT @V_COUNT = COUNT(1)
                          FROM ITEMPROIMPOS
                         WHERE CDFILIAL    = @P_CDFILIAL
                           AND NRLANCTONF  = @P_NRLANCTONF
                           AND NRSEQITPROD = @V_ITEM_NRSEQITPROD
                           AND CDIMPOSTO   = @V_IMP_CDIMPOSTO
                           AND VRPERREDBCIT > 0
                           AND NRITPROIMPOS = '2';

                        IF (@V_COUNT = 0) BEGIN
                           SET @V_TRAVA       = 'CSTREDBC';
                           SET @V_DESC        = 'Situao tributria do ICMS indica que deve haver reduo de base de clculo.';
                           SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                           SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                           SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                           INSERT INTO @TRAVAFISCAL_TABLE
                              (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                           VALUES
                              (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                        END;
                     END;
                  END
                  ELSE BEGIN
                     IF (@V_ITEM_CDFISCOPERSN IS NULL) BEGIN

                        SET @V_TRAVA       = 'ERRO_CSOSNITEM';
                        SET @V_DESC        = 'Notas com ICMS devem possuir CSOSN.';
                        SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                        SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                        SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                        INSERT INTO @TRAVAFISCAL_TABLE
                           (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                        VALUES
                           (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                     END;
                  END;
               END;
               /*ICMS, IPI, PIS, COFINS*/
               IF ((@V_IMP_CDIMPOSTONFE = '50') OR (@V_IMP_CDIMPOSTONFE = '60')) BEGIN
                  IF (@V_IMP_CDSITUTRIBITNFE IS NULL) BEGIN
                     SET @V_TRAVA       = 'ERROCSTNFE';
                     SET @V_DESC        = 'Imposto com CST vazio.';
                     SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                     SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                     SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                     INSERT INTO @TRAVAFISCAL_TABLE
                        (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                     VALUES
                        (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                  END;
               END;

               IF (@V_CDSITUCRT = '3') BEGIN
                  IF (@V_IMP_CDSITUTRIBITNFE IS NOT NULL) BEGIN
                     SELECT @V_IMPOSTO = MAX(CDIMPOSTO)
                       FROM ALIQUOTACSTNFE
                      WHERE CDIMPOSTO = @V_IMP_CDIMPOSTONFE
                        AND CDSITUTRIBNFE = @V_IMP_CDSITUTRIBITNFE;

                     IF (@V_IMPOSTO IS NOT NULL) BEGIN
                        IF ((@V_IMP_CDFISCALIT = '1') AND (@V_IMP_CDSITUTRIBITNFE IS NOT NULL)) AND (@V_IMP_NRITPROIMPOS <> '3') BEGIN

                           SELECT @V_CONFALIQ = MAX(CDIMPOSTO), @V_IMPOSTO = (CASE @V_IMP_CDIMPOSTONFE WHEN '50' THEN 'do PIS' ELSE 'da COFINS' END)
                             FROM ALIQUOTACSTNFE
                            WHERE CDIMPOSTO     = @V_IMP_CDIMPOSTONFE
                              AND CDSITUTRIBNFE = @V_IMP_CDSITUTRIBITNFE
                              AND VRALIQUOTA    = @V_IMP_VRALIQITEM;

                           IF (@V_CONFALIQ IS NULL) BEGIN
                              SET @V_TRAVA       = 'CSTALIQ';
                              SET @V_DESC        = 'Alquota invlida para a situao tributria. Consulte a tela: Alquota Vlida por CST e Imposto';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;
                        END;
                     END;
                  END;
                  IF (@V_IDENTRSAIDOP = 'E') BEGIN
                     SET @V_CDFILIMOVI = @V_CDFILIRECE;
                  END
                  ELSE BEGIN
                     SET @V_CDFILIMOVI = @V_CDFILIEMIT;
                  END;

                  SELECT @V_IDCUMUPISCOFIL= MAX(IDCUMUPISCOFIL)
                    FROM FILIAL
                   WHERE CDFILIAL = @V_CDFILIMOVI;

                  /*PIS*/
                  IF ((@V_IMP_CDIMPOSTONFE = '50')  AND (@V_IMP_CDSITUTRIBITNFE = '01')) BEGIN
                     IF (@V_IDCUMUPISCOFIL = 'N') BEGIN
                        IF (@V_IMP_VRALIQITEM <> 0.65) BEGIN
                           SET @V_TRAVA       = 'ALIQPISBAS';
                           SET @V_DESC        = 'Alquota invlida para a filiais cumulativas.';
                           SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                           SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                           SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                           INSERT INTO @TRAVAFISCAL_TABLE
                              (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                           VALUES
                              (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                        END;
                     END
                     ELSE BEGIN
                        IF (@V_IDCUMUPISCOFIL = 'S') BEGIN
                           IF (@V_IMP_VRALIQITEM <> 1.65) BEGIN
                              SET @V_TRAVA       = 'ALIQPISBAS';
                              SET @V_DESC        = 'Alquota invlida para a filiais no cumulativas.';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;
                        END;
                     END;
                  END;
                  /*COFINS*/
                  IF ((@V_IMP_CDIMPOSTONFE = '60')  AND (@V_IMP_CDSITUTRIBITNFE = '01')) BEGIN
                     IF (@V_IDCUMUPISCOFIL = 'N') BEGIN
                        IF (@V_IMP_VRALIQITEM <> 3.00) BEGIN
                           SET @V_TRAVA       = 'ALIQCOFBAS';
                           SET @V_DESC        = 'Alquota invlida para a filiais cumulativas.';
                           SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                           SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                           SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                           INSERT INTO @TRAVAFISCAL_TABLE
                              (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                           VALUES
                              (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                        END;
                     END
                     ELSE BEGIN
                        IF (@V_IDCUMUPISCOFIL = 'S') BEGIN
                           IF (@V_IMP_VRALIQITEM <> 7.60) BEGIN
                              SET @V_TRAVA       = 'ALIQCOVBAS';
                              SET @V_DESC        = 'Alquota invlida para a filiais no cumulativas.';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;
                        END;
                     END;
                  END;
                  /*PIS, COFINS*/
                  IF (((@V_IMP_CDIMPOSTONFE = '50') OR (@V_IMP_CDIMPOSTONFE = '60')) AND (@V_IMP_IDUTVLRQTDEIMPO = 'S')) BEGIN

                     IF (@V_IMP_CDSITUTRIBITNFE <> 03) BEGIN
                        SET @V_TRAVA       = 'ERROCSTQT';
                        SET @V_DESC        = 'Ao utilizar valor por quantidade o CST deve ser 03.';
                        SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                        SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                        SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                        INSERT INTO @TRAVAFISCAL_TABLE
                           (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                        VALUES
                           (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                     END;
                  END;
                  /*PIS, COFINS*/
                  IF ((@V_IMP_CDIMPOSTONFE = '50') OR (@V_IMP_CDIMPOSTONFE = '60')) BEGIN

                     IF (@V_IMP_CDSITUTRIBITNFE IN ('50', '51', '52', '53', '54', '55', '56', '60', '61', '62', '63', '64', '65', '66', '67')) BEGIN
                        IF (@V_IMP_CDTPCREDPICOITE IS NULL) BEGIN
                           SET @V_TRAVA       = 'ERROTPCRED';
                           SET @V_DESC        = 'Tipo de crdito deve ser informado.';
                           SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                           SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                           SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                           INSERT INTO @TRAVAFISCAL_TABLE
                              (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                           VALUES
                              (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                        END;

                        IF (@V_IMP_CDNATUBCALPCIT IS NULL) BEGIN
                           SET @V_TRAVA       = 'ERRONATUBC';
                           SET @V_DESC        = 'Natureza da base de clculo deve ser informada.';
                           SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                           SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                           SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                           INSERT INTO @TRAVAFISCAL_TABLE
                              (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                           VALUES
                              (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                        END;
                     END;
                  END;
                  IF (@V_IMP_CDIMPOSTONFE = '50') BEGIN

                     SELECT @V_COUNT = COUNT(*)
                       FROM ITEMPROIMPOS II, IMPOSTO I
                      WHERE II.CDFILIAL = @P_CDFILIAL
                        AND II.NRLANCTONF = @P_NRLANCTONF
                        AND II.NRSEQITPROD = @V_ITEM_NRSEQITPROD
                        AND II.CDIMPOSTO = I.CDIMPOSTO
                        AND I.CDIMPOSTONFE = '60';

                     IF @V_COUNT = 1 BEGIN
                        SELECT @V_COFINS = II.CDIMPOSTO, @V_COUNT = COUNT(1), @V_VRBASECALCIT = SUM(VRBASECALCIT), @V_CDSITUTRIBITNFE = MAX(CDSITUTRIBITNFE), @V_CDTPCREDPICOITE = MAX(CDTPCREDPICOITE), @V_CDNATUBCALPCIT = MAX(CDNATUBCALPCIT),
                               @V_IDIMPORECUP = MAX(IDIMPORECUP)
                          FROM ITEMPROIMPOS II, IMPOSTO I
                         WHERE II.CDFILIAL    = @P_CDFILIAL
                           AND II.NRLANCTONF  = @P_NRLANCTONF
                           AND II.NRSEQITPROD = @V_ITEM_NRSEQITPROD
                           AND II.CDIMPOSTO = I.CDIMPOSTO
                           AND I.CDIMPOSTONFE = '60'
                        GROUP BY II.CDIMPOSTO
                        HAVING COUNT(1) = 1;

                        IF (@V_COFINS IS NULL) BEGIN
                           SET @V_TRAVA       = 'ERROCOFINS';
                           SET @V_DESC        = 'Deve haver incidncia de ambos os impostos PIS e COFINS.';
                           SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                           SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                           SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                           INSERT INTO @TRAVAFISCAL_TABLE
                              (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                           VALUES
                              (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                        END
                        ELSE BEGIN
                           IF (@V_IMP_VRBASECALCIT <> @V_VRBASECALCIT) BEGIN
                              SET @V_TRAVA       = 'ERROBCCOF';
                              SET @V_DESC        = 'A base de clculo do PIS e do COFINS devem ser iguais.';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;
                           IF (@V_IMP_CDSITUTRIBITNFE <> @V_CDSITUTRIBITNFE) BEGIN
                              SET @V_TRAVA       = 'ERROCSTCOF';
                              SET @V_DESC        = 'A situao tributria do PIS e do COFINS devem ser iguais.';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;
                           IF (@V_IMP_CDTPCREDPICOITE <> @V_CDTPCREDPICOITE) BEGIN
                              SET @V_TRAVA       = 'ERROTPCOF';
                              SET @V_DESC        = 'O tipo de crdito do PIS e do COFINS devem ser iguais.';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;
                           IF (@V_IMP_CDNATUBCALPCIT <> @V_CDNATUBCALPCIT) BEGIN
                              SET @V_TRAVA       = 'ERRONTCOF';
                              SET @V_DESC        = 'A natureza da base de clculo do PIS e do COFINS devem ser iguais.';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;
                           IF (@V_IMP_IDIMPORECUP <> @V_IDIMPORECUP) BEGIN
                              SET @V_TRAVA       = 'ERRORECCOF';
                              SET @V_DESC        = 'Os impostos PIS e COFINS devem ter o mesmo tratamento de recuperao de impostos.';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;
                        END;
                     END;
                  END;
                  IF (@V_IMP_CDIMPOSTONFE = '60') BEGIN
                     SELECT @V_COUNT = COUNT(*)
                       FROM ITEMPROIMPOS II, IMPOSTO I
                      WHERE II.CDFILIAL = @P_CDFILIAL
                        AND II.NRLANCTONF = @P_NRLANCTONF
                        AND II.NRSEQITPROD = @V_ITEM_NRSEQITPROD
                        AND II.CDIMPOSTO = I.CDIMPOSTO
                        AND I.CDIMPOSTONFE = '50';

                     IF @V_COUNT = 1 BEGIN

                        SELECT @V_PIS = II.CDIMPOSTO, @V_COUNT = COUNT(1), @V_VRBASECALCIT = SUM(VRBASECALCIT), @V_CDSITUTRIBITNFE = MAX(CDSITUTRIBITNFE), @V_CDTPCREDPICOITE = MAX(CDTPCREDPICOITE), @V_CDNATUBCALPCIT = MAX(CDNATUBCALPCIT),
                               @V_IDIMPORECUP = MAX(IDIMPORECUP)
                          FROM ITEMPROIMPOS II, IMPOSTO I
                         WHERE II.CDFILIAL    = @P_CDFILIAL
                           AND II.NRLANCTONF  = @P_NRLANCTONF
                           AND II.NRSEQITPROD = @V_ITEM_NRSEQITPROD
                           AND II.CDIMPOSTO = I.CDIMPOSTO
                           AND I.CDIMPOSTONFE = '50'
                        GROUP BY II.CDIMPOSTO
                        HAVING COUNT(1) = 1;

                        IF (@V_PIS IS NULL) BEGIN
                           SET @V_TRAVA       = 'ERROPIS';
                           SET @V_DESC        = 'Deve haver incidncia de ambos os impostos PIS e COFINS.';
                           SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                           SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                           SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                           INSERT INTO @TRAVAFISCAL_TABLE
                              (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                           VALUES
                              (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                        END
                        ELSE BEGIN
                           IF (@V_IMP_VRBASECALCIT <> @V_VRBASECALCIT) BEGIN
                              SET @V_TRAVA       = 'ERROBCPIS';
                              SET @V_DESC        = 'A base de clculo do PIS e do COFINS devem ser iguais.';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;

                           IF (@V_IMP_CDSITUTRIBITNFE <> @V_CDSITUTRIBITNFE) BEGIN
                              SET @V_TRAVA       = 'ERROCSTPIS';
                              SET @V_DESC        = 'A situao tributria do PIS e do COFINS devem ser iguais.';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;

                           IF (@V_IMP_CDTPCREDPICOITE <> @V_CDTPCREDPICOITE) BEGIN
                              SET @V_TRAVA       = 'ERROTPPIS';
                              SET @V_DESC        = 'O tipo de crdito do PIS e do COFINS devem ser iguais.';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;

                           IF (@V_IMP_CDNATUBCALPCIT <> @V_CDNATUBCALPCIT) BEGIN
                              SET @V_TRAVA       = 'ERRONTPIS';
                              SET @V_DESC        = 'A natureza da base de clculo do PIS e do COFINS devem ser iguais.';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;

                           IF (@V_IMP_IDIMPORECUP <> @V_IDIMPORECUP) BEGIN
                              SET @V_TRAVA       = 'ERRORECPIS';
                              SET @V_DESC        = 'Os impostos PIS e COFINS devem ter o mesmo tratamento de recuperaao de impostos.';
                              SET @V_CDIMPOSTO   = @V_IMP_CDIMPOSTO;
                              SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                              SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                              INSERT INTO @TRAVAFISCAL_TABLE
                                 (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                              VALUES
                                 (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                           END;
                        END;
                     END;
                  END;
                  IF ((@V_IMP_CDNATUBCALPCIT IS NOT NULL) AND (@V_IMP_CDFISCOPERIT IS NOT NULL) AND (@V_IDENTRSAIDOP = 'E')) BEGIN
                     SELECT @V_COUNT = COUNT(1)
                       FROM NATUBCALCCFOP
                      WHERE CDFISCOPER = @V_IMP_CDFISCOPERIT
                        AND CDNATUBCPCSTNFE = @V_IMP_CDNATUBCALPCIT;

                     IF (NOT(@V_COUNT > 0)) BEGIN
                        SET @V_TRAVA = 'ERRONTCFOP';
                        SET @V_DESC  = 'CFOP do item no corresponde a natureza da base de clculo.Consulte a tela:  Natureza da base de clculo por CFOP';
                        SET @V_CDIMPOSTO = @V_IMP_CDIMPOSTO;
                        SET @V_NRSEQITPROD = @V_ITEM_NRSEQITPROD;
                        SET @V_CDREGRAIT   = @V_IMP_CDREGRAIT;

                        INSERT INTO @TRAVAFISCAL_TABLE
                           (CDIMPOSTO, NRSEQITPROD, NRSEQCONSISTE, DSCONSISTENCIA, CDARVPROD, NMPRODUTO, CDREGRAIT)
                        VALUES
                           (@V_CDIMPOSTO, @V_NRSEQITPROD, @V_TRAVA, @V_DESC,@V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_CDREGRAIT);
                     END;
                  END;
               END;
            END;

            FETCH NEXT FROM C_IMP INTO @V_IMP_CDIMPOSTO, @V_IMP_VRCONTITIMP, @V_IMP_VRBASECALCIT, @V_IMP_VRIMPOSTOIT, @V_IMP_CDSITUTRIBITNFE, @V_IMP_CDSITUTRIBIT,
                                       @V_IMP_CDFISCOPERIT, @V_IMP_CDFISCALIT, @V_IMP_CDIMPOSTONFE, @V_IMP_VRALIQITEM, @V_IMP_IDUTVLRQTDEIMPO, @V_IMP_CDTPCREDPICOITE,
                                       @V_IMP_CDNATUBCALPCIT, @V_IMP_IDIMPORECUP, @V_IMP_CDREGRAIT;
         END;
         CLOSE C_IMP;
         DEALLOCATE C_IMP;

         FETCH NEXT FROM C_ITEM INTO @V_ITEM_CDFILIAL, @V_ITEM_NRLANCTONF, @V_ITEM_NRSEQITPROD, @V_ITEM_CDFISOPEITEM, @V_ITEM_CDSITUTRIBPR,
                                     @V_ITEM_CDARVPROD, @V_ITEM_NMPRODUTO, @V_ITEM_CDFISCOPERSN;
      END;
      CLOSE C_ITEM;
      DEALLOCATE C_ITEM;
   END;
   RETURN;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'CONSISTE_FISCAL','6.19.XXX';
GO
